@@ -5,35 +5,45 @@ zval *ds_allocate_zval_buffer(zend_long length)
     return ecalloc(length, sizeof(zval));
 }
 
-static zval *_ds_truncate_zval_buffer(zval *buffer, zend_long length, zend_long used)
+uint32_t ds_next_power_of_2(uint32_t n, uint32_t min)
 {
-    zend_long i;
+    if (n < min) return min;
 
-    for (i = length; i < used; i++) {
-        zval_ptr_dtor(&buffer[i]);
+    n--;
+    n |= n >>  1;
+    n |= n >>  2;
+    n |= n >>  4;
+    n |= n >>  8;
+    n |= n >> 16;
+    n++;
+
+    return n;
+}
+
+zval *ds_reallocate_zval_buffer(
+    zval *buffer,
+    zend_long length,
+    zend_long current,
+    zend_long used
+) {
+    if (length == current) {
+        return buffer;
     }
 
-    return erealloc(buffer, length * sizeof(zval));
-}
-
-static zval *_ds_extend_zval_buffer(zval *buffer, zend_long length, zend_long used)
-{
-    zval *extended = erealloc(buffer, length * sizeof(zval));
-    memset(extended + used, 0, (length - used) * sizeof(zval));
-
-    return extended;
-}
-
-zval *ds_reallocate_zval_buffer(zval *buffer, zend_long length, zend_long used)
-{
     // Destruct zvals if we're truncating the buffer.
     if (length < used) {
-        return _ds_truncate_zval_buffer(buffer, length, used);
+        zend_long i;
+
+        for (i = length; i < used; i++) {
+            DTOR_AND_UNDEF(&buffer[i]);
+        }
     }
 
-    // Extend the buffer and clear the newly allocated memory.
-    if (length > used) {
-        return _ds_extend_zval_buffer(buffer, length, used);
+    buffer = erealloc(buffer, length * sizeof(zval));
+
+    // Clear out any new memory that was allocated.
+    if (length > current) {
+        memset(buffer + current, 0, (length - current) * sizeof(zval));
     }
 
     return buffer;
@@ -109,10 +119,10 @@ void ds_normalize_slice_args(
     zend_long idx = *offset;
     zend_long len = *length;
 
-    // If the offset is beyond is the end or the length is zero, zero both.
+    // If the offset is beyond the end or the length is zero, it's an empty slice.
     if (size == 0 || idx >= size) {
-        idx = 0;
-        len = 0;
+        *offset = 0;
+        *length = 0;
 
     } else {
 
@@ -130,10 +140,10 @@ void ds_normalize_slice_args(
         if ((idx + len) > size) {
             len = MAX(0, size - idx);
         }
-    }
 
-    *offset = idx;
-    *length = len;
+        *offset = idx;
+        *length = len;
+    }
 }
 
 void smart_str_appendz(smart_str *buffer, zval *value)
