@@ -31,6 +31,12 @@ ARGINFO_CALLABLE_RETURN_DS(                 Set_map, callback, Set);
 ARGINFO_NONE(                               Set_reverse);
 ARGINFO_NONE_RETURN_DS(                     Set_reversed, Set);
 ARGINFO_NONE(                               Set_sum);
+ARGINFO_NONE_RETURN_OBJ(                    Set_getIterator, Traversable);
+
+ARGINFO_ZVAL_RETURN_BOOL(                   Set_offsetExists, offset);
+ARGINFO_ZVAL(                               Set_offsetGet, offset);
+ARGINFO_ZVAL_ZVAL(                          Set_offsetSet, offset, value);
+ARGINFO_ZVAL(                               Set_offsetUnset, offset);
 
 void php_ds_register_set();
 
