@@ -257,12 +257,51 @@ METHOD(unshift)
     ds_vector_unshift_va(THIS_DS_VECTOR(), argc, argv);
 }
 
+METHOD(getIterator) {
+    PARSE_NONE;
+    ZVAL_COPY(return_value, getThis());
+}
+
+METHOD(offsetExists)
+{
+    PARSE_LONG(index);
+    RETURN_BOOL(ds_vector_isset(THIS_DS_VECTOR(), index, false));
+}
+
+METHOD(offsetGet)
+{
+    PARSE_LONG(index);
+    RETURN_ZVAL_COPY(ds_vector_get(THIS_DS_VECTOR(), index));
+}
+
+METHOD(offsetSet)
+{
+    PARSE_ZVAL_ZVAL(offset, value);
+
+    if (Z_TYPE_P(offset) == IS_NULL) {
+        ds_vector_push(THIS_DS_VECTOR(), value);
+    } else {
+        if (Z_TYPE_P(offset) != IS_LONG) {
+            INTEGER_INDEX_REQUIRED(offset);
+        } else {
+            ds_vector_set(THIS_DS_VECTOR(), Z_LVAL_P(offset), value);
+        }
+    }
+}
+
+METHOD(offsetUnset)
+{
+    PARSE_LONG(index);
+    ds_vector_remove(THIS_DS_VECTOR(), index, return_value);
+}
+
 void php_ds_register_vector()
 {
     zend_class_entry ce;
 
     zend_function_entry methods[] = {
         PHP_DS_ME(Vector, __construct)
+        PHP_DS_ME(Vector, getIterator)
 
         PHP_DS_SEQUENCE_ME_LIST(Vector)
         PHP_DS_COLLECTION_ME_LIST(Vector)
@@ -271,7 +310,7 @@ void php_ds_register_vector()
 
     INIT_CLASS_ENTRY(ce, PHP_DS_NS(Vector), methods);
 
-    php_ds_vector_ce = zend_register_internal_class(&ce);
+    php_ds_vector_ce                 = zend_register_internal_class(&ce);
     php_ds_vector_ce->ce_flags      |= ZEND_ACC_FINAL;
     php_ds_vector_ce->create_object  = php_ds_vector_create_object;
     php_ds_vector_ce->get_iterator   = php_ds_vector_get_iterator;
