@@ -6,9 +6,14 @@
 
 zend_object_handlers php_vector_handlers;
 
-static zval *php_ds_vector_read_dimension(zval *obj, zval *offset, int type, zval *return_value)
-{
+static zval *php_ds_vector_read_dimension
+#if PHP_VERSION_ID >= 80000
+(zend_object *obj, zval *offset, int type, zval *return_value) {
+    ds_vector_t *vector = ((php_ds_vector_t*)obj)->vector;
+#else
+(zval *obj, zval *offset, int type, zval *return_value) {
     ds_vector_t *vector = Z_DS_VECTOR_P(obj);
+#endif
     zval *value;
 
     // Dereference the offset if it's a reference.
@@ -39,12 +44,15 @@ static zval *php_ds_vector_read_dimension(zval *obj, zval *offset, int type, zva
     return value;
 }
 
-static void php_ds_vector_write_dimension(zval *obj, zval *offset, zval *value)
-{
+static void php_ds_vector_write_dimension
+#if PHP_VERSION_ID >= 80000
+(zend_object *obj, zval *offset, zval *value) {
+    ds_vector_t *vector = ((php_ds_vector_t*)obj)->vector;
+#else
+(zval *obj, zval *offset, zval *value) {
     ds_vector_t *vector = Z_DS_VECTOR_P(obj);
-
-    /* $v[] = ... */
-    if (offset == NULL) {
+#endif
+    if (offset == NULL) { /* $v[] = ... */
         ds_vector_push(vector, value);
 
     } else {
@@ -58,25 +66,34 @@ static void php_ds_vector_write_dimension(zval *obj, zval *offset, zval *value)
     }
 }
 
-static int php_ds_vector_has_dimension(zval *obj, zval *offset, int check_empty)
-{
-    ZVAL_DEREF(offset);
-
+static int php_ds_vector_has_dimension
+#if PHP_VERSION_ID >= 80000
+(zend_object *obj, zval *offset, int check_empty) {
+    ds_vector_t *vector = ((php_ds_vector_t*)obj)->vector;
+#else
+(zval *obj, zval *offset, int check_empty) {
+    ds_vector_t *vector = Z_DS_VECTOR_P(obj);
+#endif
     if (Z_TYPE_P(offset) != IS_LONG) {
         return 0;
     }
-
-    return ds_vector_isset(Z_DS_VECTOR_P(obj), Z_LVAL_P(offset), check_empty);
-}
-
-static void php_ds_vector_unset_dimension(zval *obj, zval *offset)
-{
-    zend_long index;
-    ds_vector_t *vector = Z_DS_VECTOR_P(obj);
-
     ZVAL_DEREF(offset);
 
-    if (Z_TYPE_P(offset) == IS_LONG) {
+    return ds_vector_isset(vector, Z_LVAL_P(offset), check_empty);
+}
+
+static void php_ds_vector_unset_dimension
+#if PHP_VERSION_ID >= 80000
+(zend_object *obj, zval *offset) {
+    ds_vector_t *vector = ((php_ds_vector_t*)obj)->vector;
+#else
+(zval *obj, zval *offset) {
+    ds_vector_t *vector = Z_DS_VECTOR_P(obj);
+#endif
+    zend_long index = 0;
+    ZVAL_DEREF(offset);
+
+    if (Z_TYPE_P(offset) == IS_LONG) {               
         index = Z_LVAL_P(offset);
 
     } else {
@@ -90,39 +107,55 @@ static void php_ds_vector_unset_dimension(zval *obj, zval *offset)
     }
 }
 
-static int php_ds_vector_count_elements(zval *obj, zend_long *count)
-{
-    *count = Z_DS_VECTOR_P(obj)->size;
-    return SUCCESS;
+static int php_ds_vector_count_elements
+#if PHP_VERSION_ID >= 80000
+(zend_object *obj, zend_long *count) {
+    *count = ((php_ds_vector_t*)obj)->vector->size; return SUCCESS;
+#else 
+(zval *obj, zend_long *count) {
+    *count = Z_DS_VECTOR_P(obj)->size; return SUCCESS;
+#endif 
 }
 
-static void php_ds_vector_free_object(zend_object *object)
+static void php_ds_vector_free_object(zend_object *obj)
 {
-    php_ds_vector_t *obj = (php_ds_vector_t*) object;
-    zend_object_std_dtor(&obj->std);
-    ds_vector_free(obj->vector);
+    php_ds_vector_t *vector = (php_ds_vector_t*) obj;
+    zend_object_std_dtor(&vector->std);
+    ds_vector_free(vector->vector);
 }
 
-static HashTable *php_ds_vector_get_debug_info(zval *obj, int *is_temp)
-{
-    zval arr;
+static HashTable *php_ds_vector_get_debug_info
+#if PHP_VERSION_ID >= 80000
+(zend_object *obj, int *is_temp) {
+    ds_vector_t *vector = ((php_ds_vector_t*)obj)->vector;
+#else
+(zval *obj, int *is_temp) {
     ds_vector_t *vector = Z_DS_VECTOR_P(obj);
-
+#endif    
+    zval arr;
     *is_temp = 1;
-
     ds_vector_to_array(vector, &arr);
     return Z_ARRVAL(arr);
 }
 
-static zend_object *php_ds_vector_clone_obj(zval *obj)
-{
+static zend_object *php_ds_vector_clone_obj
+#if PHP_VERSION_ID >= 80000
+(zend_object *obj) {
+    return php_ds_vector_create_clone(((php_ds_vector_t*)obj)->vector);
+#else 
+(zval *obj) {
     return php_ds_vector_create_clone(Z_DS_VECTOR_P(obj));
+#endif    
 }
 
-static HashTable *php_ds_vector_get_gc(zval *obj, zval **gc_data, int *gc_count)
-{
+static HashTable *php_ds_vector_get_gc
+#if PHP_VERSION_ID >= 80000
+(zend_object *obj, zval **gc_data, int *gc_count) {
+    ds_vector_t *vector = ((php_ds_vector_t*)obj)->vector;
+#else 
+(zval *obj, zval **gc_data, int *gc_count) {
     ds_vector_t *vector = Z_DS_VECTOR_P(obj);
-
+#endif    
     *gc_data  = vector->buffer;
     *gc_count = (int) vector->size;
 
