@@ -6,7 +6,10 @@
 
 static void php_ds_priority_queue_iterator_dtor(zend_object_iterator *iter)
 {
+    php_ds_priority_queue_iterator *iterator = (php_ds_priority_queue_iterator *) iter;
 
+    DTOR_AND_UNDEF(&iterator->intern.data);
+    OBJ_RELEASE(iterator->object);
 }
 
 static int php_ds_priority_queue_iterator_valid(zend_object_iterator *iter)
@@ -72,14 +75,15 @@ zend_object_iterator *php_ds_priority_queue_get_iterator(zend_class_entry *ce, z
 
     iterator->intern.funcs = &iterator_funcs;
     iterator->queue        = Z_DS_PRIORITY_QUEUE_P(object);
+    iterator->object       = Z_OBJ_P(object);
     iterator->position     = 0;
 
     // Add a reference to the object so that it doesn't get collected when
     // the iterated object is implict, eg. foreach ($obj->getInstance() as $value){ ... }
 #if PHP_VERSION_ID >= 70300
-    GC_ADDREF(Z_OBJ_P(object));
+    GC_ADDREF(iterator->object);
 #else
-    ++GC_REFCOUNT(Z_OBJ_P(object));
+    ++GC_REFCOUNT(iterator->object);
 #endif
 
     return (zend_object_iterator *) iterator;
